; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10

; From BBH
[Command]
name = "CPU0"
command = U,U,D,D,B,F,B,F,s,s
time = 0

[Command]
name = "CPU1"
command = U,U,D,D,B,F,B,F,a,a
time = 0

[Command]
name = "CPU2"
command = U,U,D,D,B,F,B,F,b,b
time = 0

[Command]
name = "CPU3"
command = U,U,D,D,B,F,B,F,c,c
time = 0

[Command]
name = "CPU4"
command = U,U,D,D,B,F,B,F,x,x
time = 0

[Command]
name = "CPU5"
command = U,U,D,D,B,F,B,F,y,y
time = 0

[Command]
name = "CPU6"
command = U,U,D,D,B,F,B,F,z,z
time = 0

[Command]
name = "CPU7"
command = U,U,D,D,B,F,B,F,a,b
time = 0

[Command]
name = "CPU8"
command = U,U,D,D,B,F,B,F,b,c
time = 0

[Command]
name = "CPU9"
command = U,U,D,D,B,F,B,F,a,c
time = 0

[Command]
name = "CPU10"
command = U,U,D,D,B,F,B,F,x,y
time = 0

[Command]
name = "CPU11"
command = U,U,D,D,B,F,B,F,y,z
time = 0

[Command]
name = "CPU12"
command = U,U,D,D,B,F,B,F,x,z
time = 0

[Command]
name = "CPU13"
command = U,U,D,D,B,F,B,F,a,x
time = 0

[Command]
name = "CPU14"
command = U,U,D,D,B,F,B,F,a,y
time = 0

[Command]
name = "CPU15"
command = U,U,D,D,B,F,B,F,a,z
time = 0

[Command]
name = "CPU16"
command = U,U,D,D,B,F,B,F,b,x
time = 0

[Command]
name = "CPU17"
command = U,U,D,D,B,F,B,F,b,y
time = 0

[Command]
name = "CPU18"
command = U,U,D,D,B,F,B,F,b,z
time = 0

[Command]
name = "CPU19"
command = U,U,D,D,B,F,B,F,c,x
time = 0

[Command]
name = "CPU20"
command = U,U,D,D,B,F,B,F,c,y
time = 0

[Command]
name = "CPU21"
command = U,U,D,D,B,F,B,F,c,z
time = 0

[Command]
name = "CPU22"
command = U,U,D,D,B,F,B,F,x,a
time = 0

[Command]
name = "CPU23"
command = U,U,D,D,B,F,B,F,x,b
time = 0

[Command]
name = "CPU24"
command = U,U,D,D,B,F,B,F,x,c
time = 0

[Command]
name = "CPU25"
command = U,U,D,D,B,F,B,F,y,a
time = 0

[Command]
name = "CPU26"
command = U,U,D,D,B,F,B,F,y,b
time = 0

[Command]
name = "CPU27"
command = U,U,D,D,B,F,B,F,y,c
time = 0

[Command]
name = "CPU28"
command = U,U,D,D,B,F,B,F,z,a
time = 0

[Command]
name = "CPU29"
command = U,U,D,D,B,F,B,F,z,b
time = 0

[Command]
name = "CPU30"
command = U,U,D,D,B,F,B,F,z,c
time = 0

[Command]
name = "CPU31"
command = U,U,D,D,B,F,B,F,s,s,s
time = 0


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
[Command]
name = "Kiba_Flash"
command = ~D, DF, F, x+y
time = 20

[Command]
name = "Kiba_Flash"   ;Same name as above
command = ~D, DF, F, y+z
time = 20

[Command]
name = "Kiba_Flash"   ;Same name as above
command = ~D, DF, F, z+x
time = 20

[Command]
name = "Ice_Barrage"
command = ~D, DB, B, a+b
time = 20

[Command]
name = "Ice_Barrage"   ;Same name as above
command = ~D, DB, B, b+c
time = 20

[Command]
name = "Ice_Barrage"   ;Same name as above
command = ~D, DB, B, c+a
time = 20

[Command]
name = "Trinity_Ball"
command = ~D, DF, F, a+b
time = 20

[Command]
name = "Trinity_Ball"   ;Same name as above
command = ~D, DF, F, b+c
time = 20

[Command]
name = "Trinity_Ball"   ;Same name as above
command = ~D, DF, F, c+a
time = 20
;-| Special Motions |------------------------------------------------------
[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

[Command]
name = "QCB_a"
command = ~D, DF, F, a

[Command]
name = "QCB_b"
command = ~D, DF, F, b

[Command]
name = "QCB_c"
command = ~D, DF, F, c

[Command]
name = "Rock"
command = x+a

[Command]
name = "Ice"
command = y+b
-| Special Motions |------------------------------------------------------


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.
;AI Activation
[State -1]
type = VarSet
triggerall = roundstate = 2
trigger1 = command = "CPU0"
trigger2 = command = "CPU1"
trigger3 = command = "CPU2"
trigger4 = command = "CPU3"
trigger5 = command = "CPU4"
trigger6 = command = "CPU5"
trigger7 = command = "CPU6"
trigger8 = command = "CPU7"
v = 58
value = 1

[State -1]
type = VarSet
triggerall = roundstate = 2
trigger1 = command = "CPU8"
trigger2 = command = "CPU9"
trigger3 = command = "CPU10"
trigger4 = command = "CPU11"
trigger5 = command = "CPU12"
trigger6 = command = "CPU13"
trigger7 = command = "CPU14"
trigger8 = command = "CPU15"
v = 58
value = 1

[State -1]
type = VarSet
triggerall = roundstate = 2
trigger1 = command = "CPU16"
trigger2 = command = "CPU17"
trigger3 = command = "CPU18"
trigger4 = command = "CPU19"
trigger5 = command = "CPU20"
trigger6 = command = "CPU21"
trigger7 = command = "CPU22"
trigger8 = command = "CPU23"
v = 58
value = 1

[State -1]
type = VarSet
triggerall = roundstate = 2
trigger1 = command = "CPU24"
trigger2 = command = "CPU25"
trigger3 = command = "CPU26"
trigger4 = command = "CPU27"
trigger5 = command = "CPU28"
trigger6 = command = "CPU29"
trigger7 = command = "CPU30"
trigger8 = command = "CPU31"
v = 58
value = 1

;===========================================================================
; AI Routines

; Run Forward
[State -1, Call Regice]
type = ChangeState
value = 8001
triggerall = var(58)
triggerall = !Win
triggerall = StateType = S
triggerall = StateNo != 100
triggerall = P2BodyDist X >= 100
trigger1 = ctrl
trigger1 = P2BodyDist X >= 100
trigger1 = Random <= 150

; Run Forward
[State -1, Use Trinity Ball]
type = ChangeState
value = 7000
triggerall = var(58)
triggerall = !Win
triggerall = StateType = S
triggerall = StateNo != 100
trigger1 = ctrl
trigger1 = P2BodyDist X >= 100
trigger1 = Random <= 150

; Run Forward
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = var(58)
triggerall = !Win
triggerall = StateType = S
triggerall = StateNo != 100
trigger1 = ctrl
trigger1 = P2BodyDist X >= 100
trigger1 = Random <= 150

;------------------
; Air Combo stuff
[State -1, Jump Up]
type = ChangeState
value = 42
triggerall = var(58)
triggerall = !Win
trigger1 = StateNo = 420
trigger1 = MoveHit

[State -1, First Hit]
type = ChangeState
value = 600
triggerall = var(58)
triggerall = var(3)
trigger1 = StateNo = 50
trigger1 = time > 10
trigger1 = P2BodyDist Y = [-35,20]

[State -1, Second Hit]
type = ChangeState
value = 630
triggerall = var(58)
triggerall = var(3)
trigger1 = StateNo = 600
trigger1 = MoveHit

[State -1, Third Hit]
type = ChangeState
value = 610
triggerall = var(58)
triggerall = var(3)
trigger1 = StateNo = 630
trigger1 = MoveHit

[State -1, Fourth Hit]
type = ChangeState
value = 640
triggerall = var(58)
triggerall = var(3)
trigger1 = StateNo = 610
trigger1 = MoveHit

[State -1, Fifth Hit]
type = ChangeState
value = 650
triggerall = var(58)
triggerall = var(3)
trigger1 = StateNo = 640
trigger1 = MoveHit

;--------------------------
; Initiate ground combos
[State -1, Light Attacks]
type = ChangeState
value = ifelse(Random < 400, 200, 230)
triggerall = var(58)
triggerall = !Win
trigger1 = StateType = S
trigger1 = ctrl
trigger1 = P2BodyDist X <= 90
trigger1 = P2BodyDist Y >= -35
trigger1 = P2StateType != L
trigger1 = Random <= 90

[State -1, Light Attacks]
type = ChangeState
value = ifelse(Random < 600, 400, 430)
triggerall = var(58)
triggerall = !Win
trigger1 = StateType = C
trigger1 = ctrl
trigger1 = P2BodyDist X <= 90
trigger1 = P2BodyDist Y = 0
trigger1 = P2StateType != L
trigger1 = Random <= 80

[State -1, Use Beam]
type = ChangeState
value = 1120
triggerall = var(58)
triggerall = !Win
triggerall = P2BodyDist X >= 80
triggerall = var(21) < 300
trigger1 = StateNo = 200
trigger1 = MoveHit
trigger2 = StateNo = 230
trigger2 = MoveHit
trigger3 = StateNo = 400
trigger3 = MoveHit
trigger4 = StateNo = 430
trigger4 = MoveHit

[State -1, Use Middle Punches]
type = ChangeState
value = ifelse(Random <= 499, 210, 410)
triggerall = var(58)
triggerall = !Win
triggerall = ((P2BodyDist X > 80) && (Var(21) < 300)) || (var(21) = [300,499])
trigger1 = StateNo = 200
trigger1 = MoveHit
trigger2 = StateNo = 230
trigger2 = MoveHit
trigger3 = StateNo = 400
trigger3 = MoveHit
trigger4 = StateNo = 430
trigger4 = MoveHit

[State -1, Use Trip]
type = ChangeState
value = 440
triggerall = var(58)
triggerall = !Win
triggerall = var(21) = [500,749]
trigger1 = StateNo = 200
trigger1 = MoveHit
trigger2 = StateNo = 230
trigger2 = MoveHit
trigger3 = StateNo = 400
trigger3 = MoveHit
trigger4 = StateNo = 430
trigger4 = MoveHit

[State -1, Use Lunge]
type = ChangeState
value = 226
triggerall = var(58)
triggerall = !Win
triggerall = var(21) >= 750
trigger1 = StateNo = 200
trigger1 = MoveHit
trigger2 = StateNo = 230
trigger2 = MoveHit
trigger3 = StateNo = 400
trigger3 = MoveHit
trigger4 = StateNo = 430
trigger4 = MoveHit

;---------------------------
; Combo into Kiba Flash
[State -1, Use Kiba Flash]
type = ChangeState
value = 2000
triggerall = var(58)
triggerall = !Win
triggerall = NumHelper(8000) = 0
trigger1 = StateNo = 210
trigger1 = MoveHit
trigger2 = StateNo = 410
trigger2 = MoveHit

[State -1, Punch Combo]
type = ChangeState
value = 1000
triggerall = var(58)
triggerall = !Win
triggerall = (Power < 1000) || (var(21) >= 500)
trigger1 = StateNo = 210
trigger1 = MoveHit
trigger2 = StateNo = 410
trigger2 = MoveHit

;---------------------------------
; Use moves in non-combos

[State -1, Anti-Air]
type = ChangeState
value = 220
triggerall = var(58)
triggerall = !Win
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger1 = P2StateType = A
trigger1 = EnemyNear, Vel X > 0
trigger1 = P2BodyDist X <= 75
trigger1 = P2BodyDist Y >= 190
trigger1 = Random <= 300

[State -1, Use Lunge]
type = ChangeState
value = 226
triggerall = var(58)
triggerall = !Win
triggerall = P2BodyDist X <= 170
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger1 = Random <= 8
trigger2 = ctrl
trigger2 = EnemyNear, ctrl = 0
trigger2 = P2StateType = S || P2StateType = C
trigger2 = Random <= 24

[State -1, Use Beam]
type = ChangeState
value = ifelse(Random <= 1100, 1110, ifelse(Random <= 1100, 1110, 1120))
triggerall = var(58)
triggerall = !Win
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger1 = Random <= 3
trigger2 = StateNo = 220
trigger2 = !MoveHit
trigger2 = AnimElemNo(0) > 2
trigger2 = Random <= 70
trigger3 = StateNo = 226
trigger3 = !MoveHit
trigger3 = AnimElemNo(0) > 4
trigger3 = Random <= 100
trigger4 = StateNo = 250
trigger4 = !MoveHit
trigger4 = AnimElemNo(0) > 3
trigger4 = Random <= 80
trigger5 = StateNo = 420
trigger5 = !MoveHit
trigger5 = AnimElemNo(0) > 4
trigger5 = Random <= 130
trigger6 = !MoveHit
trigger6 = StateNo = 450
trigger6 = AnimElemNo(0) > 3
trigger6 = Random <= 50

[State -1, Use Barrage]
type = ChangeState
value = 4000
triggerall = var(58)
triggerall = !Win
triggerall = NumHelper(451) = 0
triggerall = Power >= 1000
triggerall = Stateno = 0
trigger1 = ctrl
trigger1 = Random <= 2
trigger2 = ctrl
trigger2 = EnemyNear, ctrl = 0
trigger2 = P2MoveType = A || P2MoveType = H
trigger2 = (P2StateType = S) || (P2StateType = C)
trigger2 = Random <= 25

[State -1, Use Light Splash]
type = ChangeState
value = 8000
triggerall = var(58)
triggerall = !Win
triggerall = StateType = S
trigger1 = !var(3)
trigger1 = P2BodyDist X <= 100
trigger1 = ctrl
trigger1 = Random <= 30

[State -1, Use Medium and Hard Splash]
type = ChangeState
value = ifelse(Random <= 8000, 1110, 1120)
triggerall = var(58)
triggerall = !Win
triggerall = P2BodyDist X <= 170
triggerall = !var(3)
trigger1 = ctrl
trigger1 = EnemyNear, ctrl = 0
trigger1 = Random <= 20
trigger2 = Ctrl
trigger2 = StateType = S
trigger2 = P2BodyDist X <= 130
trigger2 = Random <= 50

[State -1, Use Light Punch]
type = ChangeState
value = 1000
triggerall = var(58)
triggerall = !Win
triggerall = P2BodyDist X <= 145
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger1 = EnemyNear, ctrl = 0
trigger1 = P2MoveType = A || P2MoveType = H
trigger1 = (P2StateType = S) || (P2StateType = C)
trigger1 = Random <= 40

[State -1, Use Medium Punch]
type = ChangeState
value = 1010
triggerall = var(58)
triggerall = !Win
triggerall = P2BodyDist X = [146,190]
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger1 = EnemyNear, ctrl = 0
trigger1 = P2MoveType = A || P2MoveType = H
trigger1 = (P2StateType = S) || (P2StateType = C)
trigger1 = Random <= 55

[State -1, Use Hard Punch]
type = ChangeState
value = 1020
triggerall = var(58)
triggerall = !Win
triggerall = P2BodyDist X > 190
triggerall = StateType = S || StateType = C
trigger1 = ctrl
trigger1 = EnemyNear, ctrl = 0
trigger1 = P2MoveType = A || P2MoveType = H
trigger1 = (P2StateType = S) || (P2StateType = C)
trigger1 = Random <= 65



; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;Ice Barrage
;OJt[˂iQ[WxPj
[State -1, Ice Barrage]
type = ChangeState
value = 4000
triggerall = command = "Ice_Barrage"
triggerall = power >= 1000
trigger1 = stateno = 0
trigger1 = ctrl

;Triple Kung Fu Palm (uses one super bar)
;OJt[˂iQ[WxPj
[State -1, Trinity Ball]
type = ChangeState
value = 7000
triggerall = command = "Trinity_Ball"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact


;Triple Kung Fu Palm (uses one super bar)
;OJt[˂iQ[WxPj
[State -1, Kiba Flash]
type = ChangeState
value = 2000
triggerall = command = "Kiba_Flash"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
var(1) = 1

;---------------------------------------------------------------------------
;Call Regice
;Jt[˂ij
[State -1, Regice]
type = ChangeState
value = 8001
triggerall = command = "Ice"
trigger1 = var(1) ;Use combo condition (above)

;-------------------------------------------
;Call Regirock
;Jt[˂ij
[State -1, Regirock]
type = ChangeState
value = 8000
triggerall = command = "Rock"
trigger1 = var(1) ;Use combo condition (above)


;Regi Beam (Light)
;Jt[˂iQ[WxP^Rj
[State -1, Light Beam]
type = ChangeState
value = 1100
triggerall = command = "QCB_a"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;Regi Beam (Light)
;Jt[˂iQ[WxP^Rj
[State -1, Medium Beam]
type = ChangeState
value = 1110
triggerall = command = "QCB_b"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;Regi Beam (Light)
;Jt[˂iQ[WxP^Rj
[State -1, Heavy Beam]
type = ChangeState
value = 1120
triggerall = command = "QCB_c"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Palm (1/3 super bar)
;Jt[˂iQ[WxP^Rj
[State -1, Heavy Claw]
type = ChangeState
value = 1010
triggerall = command = "QCF_z"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Light Claw]
type = ChangeState
value = 1000
triggerall = command = "QCF_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Palm
;Jt[˂ij
[State -1, Medium Claw]
type = ChangeState
value = 1010
triggerall = command = "QCF_y"
trigger1 = var(1) ;Use combo condition (above)


;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6
trigger2 = stateno = 230
trigger2 = time > 6
;---------------------------------------------------------------------------
;Stand Strong Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 240) && time > 6

;Stand Strong Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 210) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 240) && time > 6
trigger4 = (stateno = 250) && time > 6

;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 7
trigger3 = (stateno = 240) && time > 9
trigger2 = stateno = 210
trigger2 = time > 6

;Stand Light Kick
;LbN
[State -1, Stand Medium Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 7
trigger3 = (stateno = 230) && time > 9
trigger2 = stateno = 210
trigger2 = time > 6

;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 7
trigger3 = (stateno = 240) && time > 9
trigger2 = stateno = 210
trigger2 = time > 6

;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;Crouching Strong Punch
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 410) || (stateno = 440)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Medium Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)


;Crouching Heavy Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 410) || (stateno = 440)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Medium Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking

;Jump Heavy Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 610 || stateno = 640 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Medium Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Ai

;Jump Heavy Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 610 || stateno = 640 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Ai
;---------------------------------------------------------------------------

